Resolver

Struct Resolver 

pub struct Resolver {
    pub godot_items: HashMap<String, String>,
    pub rust_to_godot: HashMap<String, String>,
    pub url_overrides: HashMap<String, String>,
    pub rename_classes: HashMap<String, String>,
}
Information to resolve links.

Fields

godot_items: HashMap<String, String>

Link to godot items’ documentation.

Contains the link to godot classes, but also true, INF, Err

rust_to_godot: HashMap<String, String>

Mapping from Rust to Godot types.

url_overrides: HashMap<String, String>

User-defined overrides.

These are defined in the toml configuration file.

rename_classes: HashMap<String, String>

User-defined Rust to Godot mapping.

These are defined in the toml configuration file.

Implementations

Source

impl Resolver

pub fn resolve(&self, link: &str) -> Option<&str>

Resolve a name to the location it must link to.

link must already have been stripped off the enclosing `.